Documentation
¶
Index ¶
- Variables
- type CipherDetectionInput
- func (m *CipherDetectionInput) Clone() proto.Message
- func (*CipherDetectionInput) Descriptor() ([]byte, []int)deprecated
- func (m *CipherDetectionInput) Equal(that interface{}) bool
- func (x *CipherDetectionInput) GetPassthroughCiphers() []uint32
- func (x *CipherDetectionInput) GetTerminatingCiphers() []uint32
- func (m *CipherDetectionInput) Hash(hasher hash.Hash64) (uint64, error)
- func (*CipherDetectionInput) ProtoMessage()
- func (x *CipherDetectionInput) ProtoReflect() protoreflect.Message
- func (x *CipherDetectionInput) Reset()
- func (x *CipherDetectionInput) String() string
Constants ¶
This section is empty.
Variables ¶
var File_github_com_solo_io_gloo_projects_gloo_api_external_envoy_config_matching_inputs_cipher_detection_input_v3_cipher_detection_input_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CipherDetectionInput ¶
type CipherDetectionInput struct {
// List of TLS ciphers to send to the passthrough cipher chain. Ciphers must
// be provided using their 16-bit value. These numbers of IANA standardised
// values for all possible cipher suites and can be found here:
// https://www.iana.org/assignments/tls-parameters/tls-parameters.xhtml
//
// example: to select the following cipher
//
// 0x00,0x3c TLS_RSA_WITH_AES_128_CBC_SHA256
//
// this field should be set to 0x003c
PassthroughCiphers []uint32 `protobuf:"varint,1,rep,packed,name=passthrough_ciphers,json=passthroughCiphers,proto3" json:"passthrough_ciphers,omitempty"`
// Terminating ciphers are those that should be considered as supported.
// If not specified, defaults to whatever the current envoy implementation
// finds to be the default set of ciphers.
TerminatingCiphers []uint32 `protobuf:"varint,2,rep,packed,name=terminating_ciphers,json=terminatingCiphers,proto3" json:"terminating_ciphers,omitempty"`
// contains filtered or unexported fields
}
Specifies that matching should be performed by the destination IP address. [#extension: io.solo.matching.inputs.cipher_detection_input]
func (*CipherDetectionInput) Clone ¶
func (m *CipherDetectionInput) Clone() proto.Message
Clone function
func (*CipherDetectionInput) Descriptor
deprecated
func (*CipherDetectionInput) Descriptor() ([]byte, []int)
Deprecated: Use CipherDetectionInput.ProtoReflect.Descriptor instead.
func (*CipherDetectionInput) Equal ¶
func (m *CipherDetectionInput) Equal(that interface{}) bool
Equal function
func (*CipherDetectionInput) GetPassthroughCiphers ¶
func (x *CipherDetectionInput) GetPassthroughCiphers() []uint32
func (*CipherDetectionInput) GetTerminatingCiphers ¶ added in v1.14.7
func (x *CipherDetectionInput) GetTerminatingCiphers() []uint32
func (*CipherDetectionInput) Hash ¶
func (m *CipherDetectionInput) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*CipherDetectionInput) ProtoMessage ¶
func (*CipherDetectionInput) ProtoMessage()
func (*CipherDetectionInput) ProtoReflect ¶
func (x *CipherDetectionInput) ProtoReflect() protoreflect.Message
func (*CipherDetectionInput) Reset ¶
func (x *CipherDetectionInput) Reset()
func (*CipherDetectionInput) String ¶
func (x *CipherDetectionInput) String() string
Click to show internal directories.
Click to hide internal directories.