Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_github_com_solo_io_gloo_projects_gloo_api_external_envoy_extensions_xff_offset_solo_xff_offset_filter_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type SoloXffOffset ¶
type SoloXffOffset struct {
// The amount of addresses from the left of x-forwarded-for (xff) header
// which should be skipped to get the client address.
Offset uint32 `protobuf:"varint,1,opt,name=offset,proto3" json:"offset,omitempty"`
// contains filtered or unexported fields
}
Envoy filter configuration for the solo_xff_offset filter, not set by the user.
func (*SoloXffOffset) Descriptor
deprecated
func (*SoloXffOffset) Descriptor() ([]byte, []int)
Deprecated: Use SoloXffOffset.ProtoReflect.Descriptor instead.
func (*SoloXffOffset) GetOffset ¶
func (x *SoloXffOffset) GetOffset() uint32
func (*SoloXffOffset) ProtoMessage ¶
func (*SoloXffOffset) ProtoMessage()
func (*SoloXffOffset) ProtoReflect ¶
func (x *SoloXffOffset) ProtoReflect() protoreflect.Message
func (*SoloXffOffset) Reset ¶
func (x *SoloXffOffset) Reset()
func (*SoloXffOffset) String ¶
func (x *SoloXffOffset) String() string
Click to show internal directories.
Click to hide internal directories.