Documentation
¶
Index ¶
- Variables
- type ListenerTracingSettings
- func (m *ListenerTracingSettings) Clone() proto.Message
- func (*ListenerTracingSettings) Descriptor() ([]byte, []int)deprecated
- func (m *ListenerTracingSettings) Equal(that interface{}) bool
- func (x *ListenerTracingSettings) GetDatadogConfig() *v3.DatadogConfig
- func (x *ListenerTracingSettings) GetEnvironmentVariablesForTags() []*TracingTagEnvironmentVariable
- func (x *ListenerTracingSettings) GetLiteralsForTags() []*TracingTagLiteral
- func (x *ListenerTracingSettings) GetOpenCensusConfig() *v3.OpenCensusConfig
- func (x *ListenerTracingSettings) GetOpenTelemetryConfig() *v3.OpenTelemetryConfig
- func (m *ListenerTracingSettings) GetProviderConfig() isListenerTracingSettings_ProviderConfig
- func (x *ListenerTracingSettings) GetRequestHeadersForTags() []*wrappers.StringValue
- func (x *ListenerTracingSettings) GetTracePercentages() *TracePercentages
- func (x *ListenerTracingSettings) GetVerbose() *wrappers.BoolValue
- func (x *ListenerTracingSettings) GetZipkinConfig() *v3.ZipkinConfig
- func (m *ListenerTracingSettings) Hash(hasher hash.Hash64) (uint64, error)
- func (*ListenerTracingSettings) ProtoMessage()
- func (x *ListenerTracingSettings) ProtoReflect() protoreflect.Message
- func (x *ListenerTracingSettings) Reset()
- func (x *ListenerTracingSettings) String() string
- type ListenerTracingSettings_DatadogConfig
- type ListenerTracingSettings_OpenCensusConfig
- type ListenerTracingSettings_OpenTelemetryConfig
- type ListenerTracingSettings_ZipkinConfig
- type RouteTracingSettings
- func (m *RouteTracingSettings) Clone() proto.Message
- func (*RouteTracingSettings) Descriptor() ([]byte, []int)deprecated
- func (m *RouteTracingSettings) Equal(that interface{}) bool
- func (x *RouteTracingSettings) GetPropagate() *wrappers.BoolValue
- func (x *RouteTracingSettings) GetRouteDescriptor() string
- func (x *RouteTracingSettings) GetTracePercentages() *TracePercentages
- func (m *RouteTracingSettings) Hash(hasher hash.Hash64) (uint64, error)
- func (*RouteTracingSettings) ProtoMessage()
- func (x *RouteTracingSettings) ProtoReflect() protoreflect.Message
- func (x *RouteTracingSettings) Reset()
- func (x *RouteTracingSettings) String() string
- type TracePercentages
- func (m *TracePercentages) Clone() proto.Message
- func (*TracePercentages) Descriptor() ([]byte, []int)deprecated
- func (m *TracePercentages) Equal(that interface{}) bool
- func (x *TracePercentages) GetClientSamplePercentage() *wrappers.FloatValue
- func (x *TracePercentages) GetOverallSamplePercentage() *wrappers.FloatValue
- func (x *TracePercentages) GetRandomSamplePercentage() *wrappers.FloatValue
- func (m *TracePercentages) Hash(hasher hash.Hash64) (uint64, error)
- func (*TracePercentages) ProtoMessage()
- func (x *TracePercentages) ProtoReflect() protoreflect.Message
- func (x *TracePercentages) Reset()
- func (x *TracePercentages) String() string
- type TracingTagEnvironmentVariable
- func (m *TracingTagEnvironmentVariable) Clone() proto.Message
- func (*TracingTagEnvironmentVariable) Descriptor() ([]byte, []int)deprecated
- func (m *TracingTagEnvironmentVariable) Equal(that interface{}) bool
- func (x *TracingTagEnvironmentVariable) GetDefaultValue() *wrappers.StringValue
- func (x *TracingTagEnvironmentVariable) GetName() *wrappers.StringValue
- func (x *TracingTagEnvironmentVariable) GetTag() *wrappers.StringValue
- func (m *TracingTagEnvironmentVariable) Hash(hasher hash.Hash64) (uint64, error)
- func (*TracingTagEnvironmentVariable) ProtoMessage()
- func (x *TracingTagEnvironmentVariable) ProtoReflect() protoreflect.Message
- func (x *TracingTagEnvironmentVariable) Reset()
- func (x *TracingTagEnvironmentVariable) String() string
- type TracingTagLiteral
- func (m *TracingTagLiteral) Clone() proto.Message
- func (*TracingTagLiteral) Descriptor() ([]byte, []int)deprecated
- func (m *TracingTagLiteral) Equal(that interface{}) bool
- func (x *TracingTagLiteral) GetTag() *wrappers.StringValue
- func (x *TracingTagLiteral) GetValue() *wrappers.StringValue
- func (m *TracingTagLiteral) Hash(hasher hash.Hash64) (uint64, error)
- func (*TracingTagLiteral) ProtoMessage()
- func (x *TracingTagLiteral) ProtoReflect() protoreflect.Message
- func (x *TracingTagLiteral) Reset()
- func (x *TracingTagLiteral) String() string
Constants ¶
This section is empty.
Variables ¶
var File_github_com_solo_io_gloo_projects_gloo_api_v1_options_tracing_tracing_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ListenerTracingSettings ¶
type ListenerTracingSettings struct {
// Optional. If specified, Envoy will include the headers and header values for any matching request headers.
RequestHeadersForTags []*wrappers.StringValue `` /* 128-byte string literal not displayed */
// Optional. If true, Envoy will include logs for streaming events. Default: false.
Verbose *wrappers.BoolValue `protobuf:"bytes,2,opt,name=verbose,proto3" json:"verbose,omitempty"`
// Requests can produce traces by random sampling or when the `x-client-trace-id` header is provided.
// TracePercentages defines the limits for random, forced, and overall tracing percentages.
TracePercentages *TracePercentages `protobuf:"bytes,3,opt,name=trace_percentages,json=tracePercentages,proto3" json:"trace_percentages,omitempty"`
// Optional. If not specified, no tracing will be performed
// ProviderConfig defines the configuration for an external tracing provider.
//
// Types that are assignable to ProviderConfig:
//
// *ListenerTracingSettings_ZipkinConfig
// *ListenerTracingSettings_DatadogConfig
// *ListenerTracingSettings_OpenTelemetryConfig
// *ListenerTracingSettings_OpenCensusConfig
ProviderConfig isListenerTracingSettings_ProviderConfig `protobuf_oneof:"provider_config"`
// Optional. If specified, Envoy will include the environment variables with the given tag as tracing tags.
EnvironmentVariablesForTags []*TracingTagEnvironmentVariable `` /* 146-byte string literal not displayed */
// Optional. If specified, Envoy will include the literals with the given tag as tracing tags.
LiteralsForTags []*TracingTagLiteral `protobuf:"bytes,7,rep,name=literals_for_tags,json=literalsForTags,proto3" json:"literals_for_tags,omitempty"`
// contains filtered or unexported fields
}
Contains settings for configuring Envoy's tracing capabilities at the listener level. See [here](https://www.envoyproxy.io/docs/envoy/latest/intro/arch_overview/observability/tracing.html) for additional information on Envoy's tracing capabilities. See [here](https://docs.solo.io/gloo-edge/latest/guides/observability/tracing/) for additional information about configuring tracing with Gloo Edge.
func (*ListenerTracingSettings) Clone ¶ added in v1.8.24
func (m *ListenerTracingSettings) Clone() proto.Message
Clone function
func (*ListenerTracingSettings) Descriptor
deprecated
func (*ListenerTracingSettings) Descriptor() ([]byte, []int)
Deprecated: Use ListenerTracingSettings.ProtoReflect.Descriptor instead.
func (*ListenerTracingSettings) Equal ¶
func (m *ListenerTracingSettings) Equal(that interface{}) bool
Equal function
func (*ListenerTracingSettings) GetDatadogConfig ¶ added in v1.6.0
func (x *ListenerTracingSettings) GetDatadogConfig() *v3.DatadogConfig
func (*ListenerTracingSettings) GetEnvironmentVariablesForTags ¶ added in v1.5.21
func (x *ListenerTracingSettings) GetEnvironmentVariablesForTags() []*TracingTagEnvironmentVariable
func (*ListenerTracingSettings) GetLiteralsForTags ¶ added in v1.5.21
func (x *ListenerTracingSettings) GetLiteralsForTags() []*TracingTagLiteral
func (*ListenerTracingSettings) GetOpenCensusConfig ¶ added in v1.12.37
func (x *ListenerTracingSettings) GetOpenCensusConfig() *v3.OpenCensusConfig
func (*ListenerTracingSettings) GetOpenTelemetryConfig ¶ added in v1.12.36
func (x *ListenerTracingSettings) GetOpenTelemetryConfig() *v3.OpenTelemetryConfig
func (*ListenerTracingSettings) GetProviderConfig ¶ added in v1.6.0
func (m *ListenerTracingSettings) GetProviderConfig() isListenerTracingSettings_ProviderConfig
func (*ListenerTracingSettings) GetRequestHeadersForTags ¶
func (x *ListenerTracingSettings) GetRequestHeadersForTags() []*wrappers.StringValue
func (*ListenerTracingSettings) GetTracePercentages ¶
func (x *ListenerTracingSettings) GetTracePercentages() *TracePercentages
func (*ListenerTracingSettings) GetVerbose ¶
func (x *ListenerTracingSettings) GetVerbose() *wrappers.BoolValue
func (*ListenerTracingSettings) GetZipkinConfig ¶ added in v1.6.0
func (x *ListenerTracingSettings) GetZipkinConfig() *v3.ZipkinConfig
func (*ListenerTracingSettings) Hash ¶ added in v1.2.13
func (m *ListenerTracingSettings) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*ListenerTracingSettings) ProtoMessage ¶
func (*ListenerTracingSettings) ProtoMessage()
func (*ListenerTracingSettings) ProtoReflect ¶ added in v1.6.0
func (x *ListenerTracingSettings) ProtoReflect() protoreflect.Message
func (*ListenerTracingSettings) Reset ¶
func (x *ListenerTracingSettings) Reset()
func (*ListenerTracingSettings) String ¶
func (x *ListenerTracingSettings) String() string
type ListenerTracingSettings_DatadogConfig ¶ added in v1.6.0
type ListenerTracingSettings_DatadogConfig struct {
DatadogConfig *v3.DatadogConfig `protobuf:"bytes,5,opt,name=datadog_config,json=datadogConfig,proto3,oneof"`
}
type ListenerTracingSettings_OpenCensusConfig ¶ added in v1.12.37
type ListenerTracingSettings_OpenCensusConfig struct {
OpenCensusConfig *v3.OpenCensusConfig `protobuf:"bytes,9,opt,name=open_census_config,json=openCensusConfig,proto3,oneof"`
}
type ListenerTracingSettings_OpenTelemetryConfig ¶ added in v1.12.36
type ListenerTracingSettings_OpenTelemetryConfig struct {
OpenTelemetryConfig *v3.OpenTelemetryConfig `protobuf:"bytes,8,opt,name=open_telemetry_config,json=openTelemetryConfig,proto3,oneof"`
}
type ListenerTracingSettings_ZipkinConfig ¶ added in v1.6.0
type ListenerTracingSettings_ZipkinConfig struct {
ZipkinConfig *v3.ZipkinConfig `protobuf:"bytes,4,opt,name=zipkin_config,json=zipkinConfig,proto3,oneof"`
}
type RouteTracingSettings ¶
type RouteTracingSettings struct {
// Optional. If set, will be used to identify the route that produced the trace.
// Note that this value will be overridden if the "x-envoy-decorator-operation" header is passed.
RouteDescriptor string `protobuf:"bytes,1,opt,name=route_descriptor,json=routeDescriptor,proto3" json:"route_descriptor,omitempty"`
// Requests can produce traces by random sampling or when the `x-client-trace-id` header is provided.
// TracePercentages defines the limits for random, forced, and overall tracing percentages.
TracePercentages *TracePercentages `protobuf:"bytes,2,opt,name=trace_percentages,json=tracePercentages,proto3" json:"trace_percentages,omitempty"`
// Optional. Default is true, If set to false, the tracing headers will not propagate to the upstream.
Propagate *wrappers.BoolValue `protobuf:"bytes,3,opt,name=propagate,proto3" json:"propagate,omitempty"`
// contains filtered or unexported fields
}
Contains settings for configuring Envoy's tracing capabilities at the route level. Note: must also specify ListenerTracingSettings for the associated listener. See [here](https://www.envoyproxy.io/docs/envoy/latest/intro/arch_overview/observability/tracing.html) for additional information on Envoy's tracing capabilities. See [here](https://docs.solo.io/gloo-edge/latest/guides/observability/tracing/) for additional information about configuring tracing with Gloo Edge.
func (*RouteTracingSettings) Clone ¶ added in v1.8.24
func (m *RouteTracingSettings) Clone() proto.Message
Clone function
func (*RouteTracingSettings) Descriptor
deprecated
func (*RouteTracingSettings) Descriptor() ([]byte, []int)
Deprecated: Use RouteTracingSettings.ProtoReflect.Descriptor instead.
func (*RouteTracingSettings) Equal ¶
func (m *RouteTracingSettings) Equal(that interface{}) bool
Equal function
func (*RouteTracingSettings) GetPropagate ¶ added in v1.5.13
func (x *RouteTracingSettings) GetPropagate() *wrappers.BoolValue
func (*RouteTracingSettings) GetRouteDescriptor ¶
func (x *RouteTracingSettings) GetRouteDescriptor() string
func (*RouteTracingSettings) GetTracePercentages ¶
func (x *RouteTracingSettings) GetTracePercentages() *TracePercentages
func (*RouteTracingSettings) Hash ¶ added in v1.2.13
func (m *RouteTracingSettings) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*RouteTracingSettings) ProtoMessage ¶
func (*RouteTracingSettings) ProtoMessage()
func (*RouteTracingSettings) ProtoReflect ¶ added in v1.6.0
func (x *RouteTracingSettings) ProtoReflect() protoreflect.Message
func (*RouteTracingSettings) Reset ¶
func (x *RouteTracingSettings) Reset()
func (*RouteTracingSettings) String ¶
func (x *RouteTracingSettings) String() string
type TracePercentages ¶
type TracePercentages struct {
// Percentage of requests that should produce traces when the `x-client-trace-id` header is provided.
// optional, defaults to 100.0
// This should be a value between 0.0 and 100.0, with up to 6 significant digits.
ClientSamplePercentage *wrappers.FloatValue `` /* 129-byte string literal not displayed */
// Percentage of requests that should produce traces by random sampling.
// optional, defaults to 100.0
// This should be a value between 0.0 and 100.0, with up to 6 significant digits.
RandomSamplePercentage *wrappers.FloatValue `` /* 129-byte string literal not displayed */
// Overall percentage of requests that should produce traces.
// optional, defaults to 100.0
// This should be a value between 0.0 and 100.0, with up to 6 significant digits.
OverallSamplePercentage *wrappers.FloatValue `` /* 132-byte string literal not displayed */
// contains filtered or unexported fields
}
Requests can produce traces by random sampling or when the `x-client-trace-id` header is provided. TracePercentages defines the limits for random, forced, and overall tracing percentages.
func (*TracePercentages) Clone ¶ added in v1.8.24
func (m *TracePercentages) Clone() proto.Message
Clone function
func (*TracePercentages) Descriptor
deprecated
func (*TracePercentages) Descriptor() ([]byte, []int)
Deprecated: Use TracePercentages.ProtoReflect.Descriptor instead.
func (*TracePercentages) Equal ¶
func (m *TracePercentages) Equal(that interface{}) bool
Equal function
func (*TracePercentages) GetClientSamplePercentage ¶
func (x *TracePercentages) GetClientSamplePercentage() *wrappers.FloatValue
func (*TracePercentages) GetOverallSamplePercentage ¶
func (x *TracePercentages) GetOverallSamplePercentage() *wrappers.FloatValue
func (*TracePercentages) GetRandomSamplePercentage ¶
func (x *TracePercentages) GetRandomSamplePercentage() *wrappers.FloatValue
func (*TracePercentages) Hash ¶ added in v1.2.13
func (m *TracePercentages) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*TracePercentages) ProtoMessage ¶
func (*TracePercentages) ProtoMessage()
func (*TracePercentages) ProtoReflect ¶ added in v1.6.0
func (x *TracePercentages) ProtoReflect() protoreflect.Message
func (*TracePercentages) Reset ¶
func (x *TracePercentages) Reset()
func (*TracePercentages) String ¶
func (x *TracePercentages) String() string
type TracingTagEnvironmentVariable ¶ added in v1.5.21
type TracingTagEnvironmentVariable struct {
// Used to populate the tag name.
Tag *wrappers.StringValue `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
// Environment variable name to obtain the value to populate the tag value.
Name *wrappers.StringValue `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// When the environment variable is not found, the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue *wrappers.StringValue `protobuf:"bytes,3,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Requests can produce traces with custom tags. TracingTagEnvironmentVariable defines an environment variable which gets added as custom tag.
func (*TracingTagEnvironmentVariable) Clone ¶ added in v1.8.24
func (m *TracingTagEnvironmentVariable) Clone() proto.Message
Clone function
func (*TracingTagEnvironmentVariable) Descriptor
deprecated
added in
v1.5.21
func (*TracingTagEnvironmentVariable) Descriptor() ([]byte, []int)
Deprecated: Use TracingTagEnvironmentVariable.ProtoReflect.Descriptor instead.
func (*TracingTagEnvironmentVariable) Equal ¶ added in v1.5.21
func (m *TracingTagEnvironmentVariable) Equal(that interface{}) bool
Equal function
func (*TracingTagEnvironmentVariable) GetDefaultValue ¶ added in v1.5.21
func (x *TracingTagEnvironmentVariable) GetDefaultValue() *wrappers.StringValue
func (*TracingTagEnvironmentVariable) GetName ¶ added in v1.5.21
func (x *TracingTagEnvironmentVariable) GetName() *wrappers.StringValue
func (*TracingTagEnvironmentVariable) GetTag ¶ added in v1.5.21
func (x *TracingTagEnvironmentVariable) GetTag() *wrappers.StringValue
func (*TracingTagEnvironmentVariable) Hash ¶ added in v1.5.21
func (m *TracingTagEnvironmentVariable) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*TracingTagEnvironmentVariable) ProtoMessage ¶ added in v1.5.21
func (*TracingTagEnvironmentVariable) ProtoMessage()
func (*TracingTagEnvironmentVariable) ProtoReflect ¶ added in v1.6.25
func (x *TracingTagEnvironmentVariable) ProtoReflect() protoreflect.Message
func (*TracingTagEnvironmentVariable) Reset ¶ added in v1.5.21
func (x *TracingTagEnvironmentVariable) Reset()
func (*TracingTagEnvironmentVariable) String ¶ added in v1.5.21
func (x *TracingTagEnvironmentVariable) String() string
type TracingTagLiteral ¶ added in v1.5.21
type TracingTagLiteral struct {
// Used to populate the tag name.
Tag *wrappers.StringValue `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
// Static literal value to populate the tag value.
Value *wrappers.StringValue `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Requests can produce traces with custom tags. TracingTagLiteral defines a literal which gets added as custom tag.
func (*TracingTagLiteral) Clone ¶ added in v1.8.24
func (m *TracingTagLiteral) Clone() proto.Message
Clone function
func (*TracingTagLiteral) Descriptor
deprecated
added in
v1.5.21
func (*TracingTagLiteral) Descriptor() ([]byte, []int)
Deprecated: Use TracingTagLiteral.ProtoReflect.Descriptor instead.
func (*TracingTagLiteral) Equal ¶ added in v1.5.21
func (m *TracingTagLiteral) Equal(that interface{}) bool
Equal function
func (*TracingTagLiteral) GetTag ¶ added in v1.5.21
func (x *TracingTagLiteral) GetTag() *wrappers.StringValue
func (*TracingTagLiteral) GetValue ¶ added in v1.5.21
func (x *TracingTagLiteral) GetValue() *wrappers.StringValue
func (*TracingTagLiteral) Hash ¶ added in v1.5.21
func (m *TracingTagLiteral) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*TracingTagLiteral) ProtoMessage ¶ added in v1.5.21
func (*TracingTagLiteral) ProtoMessage()
func (*TracingTagLiteral) ProtoReflect ¶ added in v1.6.25
func (x *TracingTagLiteral) ProtoReflect() protoreflect.Message
func (*TracingTagLiteral) Reset ¶ added in v1.5.21
func (x *TracingTagLiteral) Reset()
func (*TracingTagLiteral) String ¶ added in v1.5.21
func (x *TracingTagLiteral) String() string