Documentation
¶
Index ¶
- Variables
- type HealthCheck
- func (*HealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck) GetAlwaysLogHealthCheckFailures() bool
- func (x *HealthCheck) GetCustomHealthCheck() *HealthCheck_CustomHealthCheck
- func (x *HealthCheck) GetEventLogPath() string
- func (x *HealthCheck) GetGrpcHealthCheck() *HealthCheck_GrpcHealthCheck
- func (m *HealthCheck) GetHealthChecker() isHealthCheck_HealthChecker
- func (x *HealthCheck) GetHealthyEdgeInterval() *duration.Duration
- func (x *HealthCheck) GetHealthyThreshold() *wrappers.UInt32Value
- func (x *HealthCheck) GetHttpHealthCheck() *HealthCheck_HttpHealthCheck
- func (x *HealthCheck) GetInitialJitter() *duration.Duration
- func (x *HealthCheck) GetInterval() *duration.Duration
- func (x *HealthCheck) GetIntervalJitter() *duration.Duration
- func (x *HealthCheck) GetIntervalJitterPercent() uint32
- func (x *HealthCheck) GetNoTrafficInterval() *duration.Duration
- func (x *HealthCheck) GetReuseConnection() *wrappers.BoolValue
- func (x *HealthCheck) GetTcpHealthCheck() *HealthCheck_TcpHealthCheck
- func (x *HealthCheck) GetTimeout() *duration.Duration
- func (x *HealthCheck) GetUnhealthyEdgeInterval() *duration.Duration
- func (x *HealthCheck) GetUnhealthyInterval() *duration.Duration
- func (x *HealthCheck) GetUnhealthyThreshold() *wrappers.UInt32Value
- func (m *HealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck) ProtoMessage()
- func (x *HealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck) Reset()
- func (x *HealthCheck) String() string
- type HealthCheck_CustomHealthCheck
- func (*HealthCheck_CustomHealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_CustomHealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck_CustomHealthCheck) GetConfig() *_struct.Struct
- func (m *HealthCheck_CustomHealthCheck) GetConfigType() isHealthCheck_CustomHealthCheck_ConfigType
- func (x *HealthCheck_CustomHealthCheck) GetName() string
- func (x *HealthCheck_CustomHealthCheck) GetTypedConfig() *any1.Any
- func (m *HealthCheck_CustomHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_CustomHealthCheck) ProtoMessage()
- func (x *HealthCheck_CustomHealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_CustomHealthCheck) Reset()
- func (x *HealthCheck_CustomHealthCheck) String() string
- type HealthCheck_CustomHealthCheck_
- type HealthCheck_CustomHealthCheck_Config
- type HealthCheck_CustomHealthCheck_TypedConfig
- type HealthCheck_GrpcHealthCheck
- func (*HealthCheck_GrpcHealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_GrpcHealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck_GrpcHealthCheck) GetAuthority() string
- func (x *HealthCheck_GrpcHealthCheck) GetServiceName() string
- func (m *HealthCheck_GrpcHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_GrpcHealthCheck) ProtoMessage()
- func (x *HealthCheck_GrpcHealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_GrpcHealthCheck) Reset()
- func (x *HealthCheck_GrpcHealthCheck) String() string
- type HealthCheck_GrpcHealthCheck_
- type HealthCheck_HttpHealthCheck
- func (*HealthCheck_HttpHealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_HttpHealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck_HttpHealthCheck) GetExpectedStatuses() []*_type.Int64Range
- func (x *HealthCheck_HttpHealthCheck) GetHost() string
- func (x *HealthCheck_HttpHealthCheck) GetMethod() v3.RequestMethod
- func (x *HealthCheck_HttpHealthCheck) GetPath() string
- func (x *HealthCheck_HttpHealthCheck) GetRequestHeadersToAdd() []*core.HeaderValueOption
- func (x *HealthCheck_HttpHealthCheck) GetRequestHeadersToRemove() []string
- func (x *HealthCheck_HttpHealthCheck) GetResponseAssertions() *advanced_http.ResponseAssertions
- func (x *HealthCheck_HttpHealthCheck) GetServiceName() string
- func (x *HealthCheck_HttpHealthCheck) GetUseHttp2() bool
- func (m *HealthCheck_HttpHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_HttpHealthCheck) ProtoMessage()
- func (x *HealthCheck_HttpHealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_HttpHealthCheck) Reset()
- func (x *HealthCheck_HttpHealthCheck) String() string
- type HealthCheck_HttpHealthCheck_
- type HealthCheck_Payload
- func (*HealthCheck_Payload) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_Payload) Equal(that interface{}) bool
- func (m *HealthCheck_Payload) GetPayload() isHealthCheck_Payload_Payload
- func (x *HealthCheck_Payload) GetText() string
- func (m *HealthCheck_Payload) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_Payload) ProtoMessage()
- func (x *HealthCheck_Payload) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_Payload) Reset()
- func (x *HealthCheck_Payload) String() string
- type HealthCheck_Payload_Text
- type HealthCheck_RedisHealthCheck
- func (*HealthCheck_RedisHealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_RedisHealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck_RedisHealthCheck) GetKey() string
- func (m *HealthCheck_RedisHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_RedisHealthCheck) ProtoMessage()
- func (x *HealthCheck_RedisHealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_RedisHealthCheck) Reset()
- func (x *HealthCheck_RedisHealthCheck) String() string
- type HealthCheck_TcpHealthCheck
- func (*HealthCheck_TcpHealthCheck) Descriptor() ([]byte, []int)deprecated
- func (m *HealthCheck_TcpHealthCheck) Equal(that interface{}) bool
- func (x *HealthCheck_TcpHealthCheck) GetReceive() []*HealthCheck_Payload
- func (x *HealthCheck_TcpHealthCheck) GetSend() *HealthCheck_Payload
- func (m *HealthCheck_TcpHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
- func (*HealthCheck_TcpHealthCheck) ProtoMessage()
- func (x *HealthCheck_TcpHealthCheck) ProtoReflect() protoreflect.Message
- func (x *HealthCheck_TcpHealthCheck) Reset()
- func (x *HealthCheck_TcpHealthCheck) String() string
- type HealthCheck_TcpHealthCheck_
- type HealthStatus
- func (HealthStatus) Descriptor() protoreflect.EnumDescriptor
- func (x HealthStatus) Enum() *HealthStatus
- func (HealthStatus) EnumDescriptor() ([]byte, []int)deprecated
- func (x HealthStatus) Number() protoreflect.EnumNumber
- func (x HealthStatus) String() string
- func (HealthStatus) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( HealthStatus_name = map[int32]string{ 0: "UNKNOWN", 1: "HEALTHY", 2: "UNHEALTHY", 3: "DRAINING", 4: "TIMEOUT", 5: "DEGRADED", } HealthStatus_value = map[string]int32{ "UNKNOWN": 0, "HEALTHY": 1, "UNHEALTHY": 2, "DRAINING": 3, "TIMEOUT": 4, "DEGRADED": 5, } )
Enum value maps for HealthStatus.
var File_github_com_solo_io_gloo_projects_gloo_api_external_envoy_api_v2_core_health_check_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type HealthCheck ¶
type HealthCheck struct {
// The time to wait for a health check response. If the timeout is reached the
// health check attempt will be considered a failure.
Timeout *duration.Duration `protobuf:"bytes,1,opt,name=timeout,proto3" json:"timeout,omitempty"`
// The interval between health checks.
Interval *duration.Duration `protobuf:"bytes,2,opt,name=interval,proto3" json:"interval,omitempty"`
// An optional jitter amount in milliseconds. If specified, Envoy will start health
// checking after for a random time in ms between 0 and initial_jitter. This only
// applies to the first health check.
InitialJitter *duration.Duration `protobuf:"bytes,20,opt,name=initial_jitter,json=initialJitter,proto3" json:"initial_jitter,omitempty"`
// An optional jitter amount in milliseconds. If specified, during every
// interval Envoy will add interval_jitter to the wait time.
IntervalJitter *duration.Duration `protobuf:"bytes,3,opt,name=interval_jitter,json=intervalJitter,proto3" json:"interval_jitter,omitempty"`
// An optional jitter amount as a percentage of interval_ms. If specified,
// during every interval Envoy will add interval_ms *
// interval_jitter_percent / 100 to the wait time.
//
// If interval_jitter_ms and interval_jitter_percent are both set, both of
// them will be used to increase the wait time.
IntervalJitterPercent uint32 `` /* 128-byte string literal not displayed */
// The number of unhealthy health checks required before a host is marked
// unhealthy. Note that for *http* health checking if a host responds with 503
// this threshold is ignored and the host is considered unhealthy immediately.
UnhealthyThreshold *wrappers.UInt32Value `protobuf:"bytes,4,opt,name=unhealthy_threshold,json=unhealthyThreshold,proto3" json:"unhealthy_threshold,omitempty"`
// The number of healthy health checks required before a host is marked
// healthy. Note that during startup, only a single successful health check is
// required to mark a host healthy.
HealthyThreshold *wrappers.UInt32Value `protobuf:"bytes,5,opt,name=healthy_threshold,json=healthyThreshold,proto3" json:"healthy_threshold,omitempty"`
// Reuse health check connection between health checks. Default is true.
ReuseConnection *wrappers.BoolValue `protobuf:"bytes,7,opt,name=reuse_connection,json=reuseConnection,proto3" json:"reuse_connection,omitempty"`
// Types that are assignable to HealthChecker:
//
// *HealthCheck_HttpHealthCheck_
// *HealthCheck_TcpHealthCheck_
// *HealthCheck_GrpcHealthCheck_
// *HealthCheck_CustomHealthCheck_
HealthChecker isHealthCheck_HealthChecker `protobuf_oneof:"health_checker"`
// The "no traffic interval" is a special health check interval that is used when a cluster has
// never had traffic routed to it. This lower interval allows cluster information to be kept up to
// date, without sending a potentially large amount of active health checking traffic for no
// reason. Once a cluster has been used for traffic routing, Envoy will shift back to using the
// standard health check interval that is defined. Note that this interval takes precedence over
// any other.
//
// The default value for "no traffic interval" is 60 seconds.
NoTrafficInterval *duration.Duration `protobuf:"bytes,12,opt,name=no_traffic_interval,json=noTrafficInterval,proto3" json:"no_traffic_interval,omitempty"`
// The "unhealthy interval" is a health check interval that is used for hosts that are marked as
// unhealthy. As soon as the host is marked as healthy, Envoy will shift back to using the
// standard health check interval that is defined.
//
// The default value for "unhealthy interval" is the same as "interval".
UnhealthyInterval *duration.Duration `protobuf:"bytes,14,opt,name=unhealthy_interval,json=unhealthyInterval,proto3" json:"unhealthy_interval,omitempty"`
// The "unhealthy edge interval" is a special health check interval that is used for the first
// health check right after a host is marked as unhealthy. For subsequent health checks
// Envoy will shift back to using either "unhealthy interval" if present or the standard health
// check interval that is defined.
//
// The default value for "unhealthy edge interval" is the same as "unhealthy interval".
UnhealthyEdgeInterval *duration.Duration `` /* 127-byte string literal not displayed */
// The "healthy edge interval" is a special health check interval that is used for the first
// health check right after a host is marked as healthy. For subsequent health checks
// Envoy will shift back to using the standard health check interval that is defined.
//
// The default value for "healthy edge interval" is the same as the default interval.
HealthyEdgeInterval *duration.Duration `protobuf:"bytes,16,opt,name=healthy_edge_interval,json=healthyEdgeInterval,proto3" json:"healthy_edge_interval,omitempty"`
// Specifies the path to the `health check event log (arch_overview_health_check_logging)`.
// If empty, no event log will be written.
EventLogPath string `protobuf:"bytes,17,opt,name=event_log_path,json=eventLogPath,proto3" json:"event_log_path,omitempty"`
// If set to true, health check failure events will always be logged. If set to false, only the
// initial health check failure event will be logged.
// The default value is false.
AlwaysLogHealthCheckFailures bool `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*HealthCheck) Descriptor
deprecated
func (*HealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck) GetAlwaysLogHealthCheckFailures ¶
func (x *HealthCheck) GetAlwaysLogHealthCheckFailures() bool
func (*HealthCheck) GetCustomHealthCheck ¶
func (x *HealthCheck) GetCustomHealthCheck() *HealthCheck_CustomHealthCheck
func (*HealthCheck) GetEventLogPath ¶
func (x *HealthCheck) GetEventLogPath() string
func (*HealthCheck) GetGrpcHealthCheck ¶
func (x *HealthCheck) GetGrpcHealthCheck() *HealthCheck_GrpcHealthCheck
func (*HealthCheck) GetHealthChecker ¶
func (m *HealthCheck) GetHealthChecker() isHealthCheck_HealthChecker
func (*HealthCheck) GetHealthyEdgeInterval ¶
func (x *HealthCheck) GetHealthyEdgeInterval() *duration.Duration
func (*HealthCheck) GetHealthyThreshold ¶
func (x *HealthCheck) GetHealthyThreshold() *wrappers.UInt32Value
func (*HealthCheck) GetHttpHealthCheck ¶
func (x *HealthCheck) GetHttpHealthCheck() *HealthCheck_HttpHealthCheck
func (*HealthCheck) GetInitialJitter ¶
func (x *HealthCheck) GetInitialJitter() *duration.Duration
func (*HealthCheck) GetInterval ¶
func (x *HealthCheck) GetInterval() *duration.Duration
func (*HealthCheck) GetIntervalJitter ¶
func (x *HealthCheck) GetIntervalJitter() *duration.Duration
func (*HealthCheck) GetIntervalJitterPercent ¶
func (x *HealthCheck) GetIntervalJitterPercent() uint32
func (*HealthCheck) GetNoTrafficInterval ¶
func (x *HealthCheck) GetNoTrafficInterval() *duration.Duration
func (*HealthCheck) GetReuseConnection ¶
func (x *HealthCheck) GetReuseConnection() *wrappers.BoolValue
func (*HealthCheck) GetTcpHealthCheck ¶
func (x *HealthCheck) GetTcpHealthCheck() *HealthCheck_TcpHealthCheck
func (*HealthCheck) GetTimeout ¶
func (x *HealthCheck) GetTimeout() *duration.Duration
func (*HealthCheck) GetUnhealthyEdgeInterval ¶
func (x *HealthCheck) GetUnhealthyEdgeInterval() *duration.Duration
func (*HealthCheck) GetUnhealthyInterval ¶
func (x *HealthCheck) GetUnhealthyInterval() *duration.Duration
func (*HealthCheck) GetUnhealthyThreshold ¶
func (x *HealthCheck) GetUnhealthyThreshold() *wrappers.UInt32Value
func (*HealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck) ProtoMessage ¶
func (*HealthCheck) ProtoMessage()
func (*HealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck) Reset ¶
func (x *HealthCheck) Reset()
func (*HealthCheck) String ¶
func (x *HealthCheck) String() string
type HealthCheck_CustomHealthCheck ¶
type HealthCheck_CustomHealthCheck struct {
// The registered name of the custom health checker.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// A custom health checker specific configuration which depends on the custom health checker
// being instantiated. See :api:`envoy/config/health_checker` for reference.
//
// Types that are assignable to ConfigType:
//
// *HealthCheck_CustomHealthCheck_Config
// *HealthCheck_CustomHealthCheck_TypedConfig
ConfigType isHealthCheck_CustomHealthCheck_ConfigType `protobuf_oneof:"config_type"`
// contains filtered or unexported fields
}
Custom health check.
func (*HealthCheck_CustomHealthCheck) Descriptor
deprecated
func (*HealthCheck_CustomHealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_CustomHealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck_CustomHealthCheck) Equal ¶
func (m *HealthCheck_CustomHealthCheck) Equal(that interface{}) bool
Equal function
func (*HealthCheck_CustomHealthCheck) GetConfig ¶
func (x *HealthCheck_CustomHealthCheck) GetConfig() *_struct.Struct
func (*HealthCheck_CustomHealthCheck) GetConfigType ¶
func (m *HealthCheck_CustomHealthCheck) GetConfigType() isHealthCheck_CustomHealthCheck_ConfigType
func (*HealthCheck_CustomHealthCheck) GetName ¶
func (x *HealthCheck_CustomHealthCheck) GetName() string
func (*HealthCheck_CustomHealthCheck) GetTypedConfig ¶
func (x *HealthCheck_CustomHealthCheck) GetTypedConfig() *any1.Any
func (*HealthCheck_CustomHealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck_CustomHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_CustomHealthCheck) ProtoMessage ¶
func (*HealthCheck_CustomHealthCheck) ProtoMessage()
func (*HealthCheck_CustomHealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_CustomHealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck_CustomHealthCheck) Reset ¶
func (x *HealthCheck_CustomHealthCheck) Reset()
func (*HealthCheck_CustomHealthCheck) String ¶
func (x *HealthCheck_CustomHealthCheck) String() string
type HealthCheck_CustomHealthCheck_ ¶
type HealthCheck_CustomHealthCheck_ struct {
// Custom health check.
CustomHealthCheck *HealthCheck_CustomHealthCheck `protobuf:"bytes,13,opt,name=custom_health_check,json=customHealthCheck,proto3,oneof"`
}
type HealthCheck_GrpcHealthCheck ¶
type HealthCheck_GrpcHealthCheck struct {
// An optional service name parameter which will be sent to gRPC service in
// `grpc.health.v1.HealthCheckRequest
// <https://github.com/grpc/grpc/blob/master/src/proto/grpc/health/v1/health.proto#L20>`_.
// message. See `gRPC health-checking overview
// <https://github.com/grpc/grpc/blob/master/doc/health-checking.md>`_ for more information.
ServiceName string `protobuf:"bytes,1,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// The value of the :authority header in the gRPC health check request. If
// left empty (default value), the name of the cluster this health check is associated
// with will be used.
Authority string `protobuf:"bytes,2,opt,name=authority,proto3" json:"authority,omitempty"`
// contains filtered or unexported fields
}
`grpc.health.v1.Health <https://github.com/grpc/grpc/blob/master/src/proto/grpc/health/v1/health.proto>`_-based healthcheck. See `gRPC doc <https://github.com/grpc/grpc/blob/master/doc/health-checking.md>`_ for details.
func (*HealthCheck_GrpcHealthCheck) Descriptor
deprecated
func (*HealthCheck_GrpcHealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_GrpcHealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck_GrpcHealthCheck) Equal ¶
func (m *HealthCheck_GrpcHealthCheck) Equal(that interface{}) bool
Equal function
func (*HealthCheck_GrpcHealthCheck) GetAuthority ¶
func (x *HealthCheck_GrpcHealthCheck) GetAuthority() string
func (*HealthCheck_GrpcHealthCheck) GetServiceName ¶
func (x *HealthCheck_GrpcHealthCheck) GetServiceName() string
func (*HealthCheck_GrpcHealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck_GrpcHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_GrpcHealthCheck) ProtoMessage ¶
func (*HealthCheck_GrpcHealthCheck) ProtoMessage()
func (*HealthCheck_GrpcHealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_GrpcHealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck_GrpcHealthCheck) Reset ¶
func (x *HealthCheck_GrpcHealthCheck) Reset()
func (*HealthCheck_GrpcHealthCheck) String ¶
func (x *HealthCheck_GrpcHealthCheck) String() string
type HealthCheck_GrpcHealthCheck_ ¶
type HealthCheck_GrpcHealthCheck_ struct {
// gRPC health check.
GrpcHealthCheck *HealthCheck_GrpcHealthCheck `protobuf:"bytes,11,opt,name=grpc_health_check,json=grpcHealthCheck,proto3,oneof"`
}
type HealthCheck_HttpHealthCheck ¶
type HealthCheck_HttpHealthCheck struct {
// The value of the host header in the HTTP health check request. If
// left empty (default value), the name of the cluster this health check is associated
// with will be used.
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// Specifies the HTTP path that will be requested during health checking. For example
// */healthcheck*.
Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// An optional service name parameter which is used to validate the identity of
// the health checked cluster. See the `architecture overview
// (arch_overview_health_checking_identity)` for more information.
ServiceName string `protobuf:"bytes,5,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// Specifies a list of HTTP headers that should be added to each request that is sent to the
// health checked cluster. For more information, including details on header value syntax, see
// the documentation on `custom request headers
// (config_http_conn_man_headers_custom_request_headers)`.
RequestHeadersToAdd []*core.HeaderValueOption `protobuf:"bytes,6,rep,name=request_headers_to_add,json=requestHeadersToAdd,proto3" json:"request_headers_to_add,omitempty"`
// Specifies a list of HTTP headers that should be removed from each request that is sent to the
// health checked cluster.
RequestHeadersToRemove []string `` /* 131-byte string literal not displayed */
// If set, health checks will be made using http/2.
UseHttp2 bool `protobuf:"varint,7,opt,name=use_http2,json=useHttp2,proto3" json:"use_http2,omitempty"`
// Specifies a list of HTTP response statuses considered healthy. If provided, replaces default
// 200-only policy - 200 must be included explicitly as needed. Ranges follow half-open
// semantics of `Int64Range (envoy_api_msg_type.Int64Range)`.
ExpectedStatuses []*_type.Int64Range `protobuf:"bytes,9,rep,name=expected_statuses,json=expectedStatuses,proto3" json:"expected_statuses,omitempty"`
// (Enterprise Only): If defined, the response health check rules take precedence over the http
// `expected_statuses`.
ResponseAssertions *advanced_http.ResponseAssertions `protobuf:"bytes,10,opt,name=response_assertions,json=responseAssertions,proto3" json:"response_assertions,omitempty"`
// HTTP Method that will be used for health checking, default is "GET".
// GET, HEAD, POST, PUT, DELETE, OPTIONS, TRACE, PATCH methods are supported, but making request body is not supported.
// CONNECT method is disallowed because it is not appropriate for health check request.
// If a non-200 response is expected by the method, it needs to be set in :ref:`expected_statuses <envoy_v3_api_field_config.core.v3.HealthCheck.HttpHealthCheck.expected_statuses>`.
Method v3.RequestMethod `protobuf:"varint,11,opt,name=method,proto3,enum=solo.io.envoy.config.core.v3.RequestMethod" json:"method,omitempty"`
// contains filtered or unexported fields
}
[#comment:next free field: 11]
func (*HealthCheck_HttpHealthCheck) Descriptor
deprecated
func (*HealthCheck_HttpHealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_HttpHealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck_HttpHealthCheck) Equal ¶
func (m *HealthCheck_HttpHealthCheck) Equal(that interface{}) bool
Equal function
func (*HealthCheck_HttpHealthCheck) GetExpectedStatuses ¶
func (x *HealthCheck_HttpHealthCheck) GetExpectedStatuses() []*_type.Int64Range
func (*HealthCheck_HttpHealthCheck) GetHost ¶
func (x *HealthCheck_HttpHealthCheck) GetHost() string
func (*HealthCheck_HttpHealthCheck) GetMethod ¶ added in v1.14.0
func (x *HealthCheck_HttpHealthCheck) GetMethod() v3.RequestMethod
func (*HealthCheck_HttpHealthCheck) GetPath ¶
func (x *HealthCheck_HttpHealthCheck) GetPath() string
func (*HealthCheck_HttpHealthCheck) GetRequestHeadersToAdd ¶
func (x *HealthCheck_HttpHealthCheck) GetRequestHeadersToAdd() []*core.HeaderValueOption
func (*HealthCheck_HttpHealthCheck) GetRequestHeadersToRemove ¶
func (x *HealthCheck_HttpHealthCheck) GetRequestHeadersToRemove() []string
func (*HealthCheck_HttpHealthCheck) GetResponseAssertions ¶ added in v1.8.0
func (x *HealthCheck_HttpHealthCheck) GetResponseAssertions() *advanced_http.ResponseAssertions
func (*HealthCheck_HttpHealthCheck) GetServiceName ¶
func (x *HealthCheck_HttpHealthCheck) GetServiceName() string
func (*HealthCheck_HttpHealthCheck) GetUseHttp2 ¶
func (x *HealthCheck_HttpHealthCheck) GetUseHttp2() bool
func (*HealthCheck_HttpHealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck_HttpHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_HttpHealthCheck) ProtoMessage ¶
func (*HealthCheck_HttpHealthCheck) ProtoMessage()
func (*HealthCheck_HttpHealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_HttpHealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck_HttpHealthCheck) Reset ¶
func (x *HealthCheck_HttpHealthCheck) Reset()
func (*HealthCheck_HttpHealthCheck) String ¶
func (x *HealthCheck_HttpHealthCheck) String() string
type HealthCheck_HttpHealthCheck_ ¶
type HealthCheck_HttpHealthCheck_ struct {
// HTTP health check.
HttpHealthCheck *HealthCheck_HttpHealthCheck `protobuf:"bytes,8,opt,name=http_health_check,json=httpHealthCheck,proto3,oneof"`
}
type HealthCheck_Payload ¶
type HealthCheck_Payload struct {
// Types that are assignable to Payload:
//
// *HealthCheck_Payload_Text
Payload isHealthCheck_Payload_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
Describes the encoding of the payload bytes in the payload.
func (*HealthCheck_Payload) Descriptor
deprecated
func (*HealthCheck_Payload) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_Payload.ProtoReflect.Descriptor instead.
func (*HealthCheck_Payload) Equal ¶
func (m *HealthCheck_Payload) Equal(that interface{}) bool
Equal function
func (*HealthCheck_Payload) GetPayload ¶
func (m *HealthCheck_Payload) GetPayload() isHealthCheck_Payload_Payload
func (*HealthCheck_Payload) GetText ¶
func (x *HealthCheck_Payload) GetText() string
func (*HealthCheck_Payload) Hash ¶ added in v1.2.13
func (m *HealthCheck_Payload) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_Payload) ProtoMessage ¶
func (*HealthCheck_Payload) ProtoMessage()
func (*HealthCheck_Payload) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_Payload) ProtoReflect() protoreflect.Message
func (*HealthCheck_Payload) Reset ¶
func (x *HealthCheck_Payload) Reset()
func (*HealthCheck_Payload) String ¶
func (x *HealthCheck_Payload) String() string
type HealthCheck_Payload_Text ¶
type HealthCheck_Payload_Text struct {
// Hex encoded payload. E.g., "000000FF".
Text string `protobuf:"bytes,1,opt,name=text,proto3,oneof"`
}
type HealthCheck_RedisHealthCheck ¶
type HealthCheck_RedisHealthCheck struct {
// If set, optionally perform “EXISTS <key>“ instead of “PING“. A return value
// from Redis of 0 (does not exist) is considered a passing healthcheck. A return value other
// than 0 is considered a failure. This allows the user to mark a Redis instance for maintenance
// by setting the specified key to any value and waiting for traffic to drain.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*HealthCheck_RedisHealthCheck) Descriptor
deprecated
func (*HealthCheck_RedisHealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_RedisHealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck_RedisHealthCheck) Equal ¶
func (m *HealthCheck_RedisHealthCheck) Equal(that interface{}) bool
Equal function
func (*HealthCheck_RedisHealthCheck) GetKey ¶
func (x *HealthCheck_RedisHealthCheck) GetKey() string
func (*HealthCheck_RedisHealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck_RedisHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_RedisHealthCheck) ProtoMessage ¶
func (*HealthCheck_RedisHealthCheck) ProtoMessage()
func (*HealthCheck_RedisHealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_RedisHealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck_RedisHealthCheck) Reset ¶
func (x *HealthCheck_RedisHealthCheck) Reset()
func (*HealthCheck_RedisHealthCheck) String ¶
func (x *HealthCheck_RedisHealthCheck) String() string
type HealthCheck_TcpHealthCheck ¶
type HealthCheck_TcpHealthCheck struct {
// Empty payloads imply a connect-only health check.
Send *HealthCheck_Payload `protobuf:"bytes,1,opt,name=send,proto3" json:"send,omitempty"`
// When checking the response, “fuzzy” matching is performed such that each
// binary block must be found, and in the order specified, but not
// necessarily contiguous.
Receive []*HealthCheck_Payload `protobuf:"bytes,2,rep,name=receive,proto3" json:"receive,omitempty"`
// contains filtered or unexported fields
}
func (*HealthCheck_TcpHealthCheck) Descriptor
deprecated
func (*HealthCheck_TcpHealthCheck) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheck_TcpHealthCheck.ProtoReflect.Descriptor instead.
func (*HealthCheck_TcpHealthCheck) Equal ¶
func (m *HealthCheck_TcpHealthCheck) Equal(that interface{}) bool
Equal function
func (*HealthCheck_TcpHealthCheck) GetReceive ¶
func (x *HealthCheck_TcpHealthCheck) GetReceive() []*HealthCheck_Payload
func (*HealthCheck_TcpHealthCheck) GetSend ¶
func (x *HealthCheck_TcpHealthCheck) GetSend() *HealthCheck_Payload
func (*HealthCheck_TcpHealthCheck) Hash ¶ added in v1.2.13
func (m *HealthCheck_TcpHealthCheck) Hash(hasher hash.Hash64) (uint64, error)
Hash function
func (*HealthCheck_TcpHealthCheck) ProtoMessage ¶
func (*HealthCheck_TcpHealthCheck) ProtoMessage()
func (*HealthCheck_TcpHealthCheck) ProtoReflect ¶ added in v1.6.0
func (x *HealthCheck_TcpHealthCheck) ProtoReflect() protoreflect.Message
func (*HealthCheck_TcpHealthCheck) Reset ¶
func (x *HealthCheck_TcpHealthCheck) Reset()
func (*HealthCheck_TcpHealthCheck) String ¶
func (x *HealthCheck_TcpHealthCheck) String() string
type HealthCheck_TcpHealthCheck_ ¶
type HealthCheck_TcpHealthCheck_ struct {
// TCP health check.
TcpHealthCheck *HealthCheck_TcpHealthCheck `protobuf:"bytes,9,opt,name=tcp_health_check,json=tcpHealthCheck,proto3,oneof"`
}
type HealthStatus ¶
type HealthStatus int32
Endpoint health status.
const ( // The health status is not known. This is interpreted by Envoy as *HEALTHY*. HealthStatus_UNKNOWN HealthStatus = 0 // Healthy. HealthStatus_HEALTHY HealthStatus = 1 // Unhealthy. HealthStatus_UNHEALTHY HealthStatus = 2 // Connection draining in progress. E.g., // `<https://aws.amazon.com/blogs/aws/elb-connection-draining-remove-instances-from-service-with-care/>`_ // or // `<https://cloud.google.com/compute/docs/load-balancing/enabling-connection-draining>`_. // This is interpreted by Envoy as *UNHEALTHY*. HealthStatus_DRAINING HealthStatus = 3 // Health check timed out. This is part of HDS and is interpreted by Envoy as // *UNHEALTHY*. HealthStatus_TIMEOUT HealthStatus = 4 // Degraded. HealthStatus_DEGRADED HealthStatus = 5 )
func (HealthStatus) Descriptor ¶ added in v1.6.0
func (HealthStatus) Descriptor() protoreflect.EnumDescriptor
func (HealthStatus) Enum ¶ added in v1.6.0
func (x HealthStatus) Enum() *HealthStatus
func (HealthStatus) EnumDescriptor
deprecated
func (HealthStatus) EnumDescriptor() ([]byte, []int)
Deprecated: Use HealthStatus.Descriptor instead.
func (HealthStatus) Number ¶ added in v1.6.0
func (x HealthStatus) Number() protoreflect.EnumNumber
func (HealthStatus) String ¶
func (x HealthStatus) String() string
func (HealthStatus) Type ¶ added in v1.6.0
func (HealthStatus) Type() protoreflect.EnumType