Documentation
¶
Index ¶
- Variables
- type DoubleRange
- func (m *DoubleRange) Clone() proto.Message
- func (*DoubleRange) Descriptor() ([]byte, []int)deprecated
- func (m *DoubleRange) Equal(that interface{}) bool
- func (x *DoubleRange) GetEnd() float64
- func (x *DoubleRange) GetStart() float64
- func (m *DoubleRange) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *DoubleRange) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*DoubleRange) ProtoMessage()
- func (x *DoubleRange) ProtoReflect() protoreflect.Message
- func (x *DoubleRange) Reset()
- func (x *DoubleRange) String() string
- type Int64Range
- func (m *Int64Range) Clone() proto.Message
- func (*Int64Range) Descriptor() ([]byte, []int)deprecated
- func (m *Int64Range) Equal(that interface{}) bool
- func (x *Int64Range) GetEnd() int64
- func (x *Int64Range) GetStart() int64
- func (m *Int64Range) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *Int64Range) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*Int64Range) ProtoMessage()
- func (x *Int64Range) ProtoReflect() protoreflect.Message
- func (x *Int64Range) Reset()
- func (x *Int64Range) String() string
Constants ¶
This section is empty.
Variables ¶
var File_github_com_solo_io_gloo_projects_gloo_api_external_envoy_type_range_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DoubleRange ¶
type DoubleRange struct {
// start of the range (inclusive)
Start float64 `protobuf:"fixed64,1,opt,name=start,proto3" json:"start,omitempty"`
// end of the range (exclusive)
End float64 `protobuf:"fixed64,2,opt,name=end,proto3" json:"end,omitempty"`
// contains filtered or unexported fields
}
Specifies the double start and end of the range using half-open interval semantics [start, end).
func (*DoubleRange) Clone ¶ added in v1.8.24
func (m *DoubleRange) Clone() proto.Message
Clone function
func (*DoubleRange) Descriptor
deprecated
func (*DoubleRange) Descriptor() ([]byte, []int)
Deprecated: Use DoubleRange.ProtoReflect.Descriptor instead.
func (*DoubleRange) GetEnd ¶
func (x *DoubleRange) GetEnd() float64
func (*DoubleRange) GetStart ¶
func (x *DoubleRange) GetStart() float64
func (*DoubleRange) Hash
deprecated
added in
v1.2.13
func (m *DoubleRange) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*DoubleRange) HashUnique ¶ added in v1.17.38
func (m *DoubleRange) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*DoubleRange) ProtoMessage ¶
func (*DoubleRange) ProtoMessage()
func (*DoubleRange) ProtoReflect ¶ added in v1.6.0
func (x *DoubleRange) ProtoReflect() protoreflect.Message
func (*DoubleRange) Reset ¶
func (x *DoubleRange) Reset()
func (*DoubleRange) String ¶
func (x *DoubleRange) String() string
type Int64Range ¶
type Int64Range struct {
// start of the range (inclusive)
Start int64 `protobuf:"varint,1,opt,name=start,proto3" json:"start,omitempty"`
// end of the range (exclusive)
End int64 `protobuf:"varint,2,opt,name=end,proto3" json:"end,omitempty"`
// contains filtered or unexported fields
}
Specifies the int64 start and end of the range using half-open interval semantics [start, end).
func (*Int64Range) Clone ¶ added in v1.8.24
func (m *Int64Range) Clone() proto.Message
Clone function
func (*Int64Range) Descriptor
deprecated
func (*Int64Range) Descriptor() ([]byte, []int)
Deprecated: Use Int64Range.ProtoReflect.Descriptor instead.
func (*Int64Range) GetEnd ¶
func (x *Int64Range) GetEnd() int64
func (*Int64Range) GetStart ¶
func (x *Int64Range) GetStart() int64
func (*Int64Range) Hash
deprecated
added in
v1.2.13
func (m *Int64Range) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*Int64Range) HashUnique ¶ added in v1.17.38
func (m *Int64Range) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*Int64Range) ProtoMessage ¶
func (*Int64Range) ProtoMessage()
func (*Int64Range) ProtoReflect ¶ added in v1.6.0
func (x *Int64Range) ProtoReflect() protoreflect.Message
func (*Int64Range) Reset ¶
func (x *Int64Range) Reset()
func (*Int64Range) String ¶
func (x *Int64Range) String() string