Documentation
¶
Index ¶
- Variables
- type CustomTag
- func (m *CustomTag) Clone() proto.Message
- func (*CustomTag) Descriptor() ([]byte, []int)deprecated
- func (m *CustomTag) Equal(that interface{}) bool
- func (x *CustomTag) GetEnvironment() *CustomTag_Environment
- func (x *CustomTag) GetLiteral() *CustomTag_Literal
- func (x *CustomTag) GetMetadata() *CustomTag_Metadata
- func (x *CustomTag) GetRequestHeader() *CustomTag_Header
- func (x *CustomTag) GetTag() string
- func (m *CustomTag) GetType() isCustomTag_Type
- func (m *CustomTag) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *CustomTag) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*CustomTag) ProtoMessage()
- func (x *CustomTag) ProtoReflect() protoreflect.Message
- func (x *CustomTag) Reset()
- func (x *CustomTag) String() string
- type CustomTag_Environment
- func (m *CustomTag_Environment) Clone() proto.Message
- func (*CustomTag_Environment) Descriptor() ([]byte, []int)deprecated
- func (m *CustomTag_Environment) Equal(that interface{}) bool
- func (x *CustomTag_Environment) GetDefaultValue() string
- func (x *CustomTag_Environment) GetName() string
- func (m *CustomTag_Environment) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *CustomTag_Environment) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*CustomTag_Environment) ProtoMessage()
- func (x *CustomTag_Environment) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Environment) Reset()
- func (x *CustomTag_Environment) String() string
- type CustomTag_Environment_
- type CustomTag_Header
- func (m *CustomTag_Header) Clone() proto.Message
- func (*CustomTag_Header) Descriptor() ([]byte, []int)deprecated
- func (m *CustomTag_Header) Equal(that interface{}) bool
- func (x *CustomTag_Header) GetDefaultValue() string
- func (x *CustomTag_Header) GetName() string
- func (m *CustomTag_Header) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *CustomTag_Header) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*CustomTag_Header) ProtoMessage()
- func (x *CustomTag_Header) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Header) Reset()
- func (x *CustomTag_Header) String() string
- type CustomTag_Literal
- func (m *CustomTag_Literal) Clone() proto.Message
- func (*CustomTag_Literal) Descriptor() ([]byte, []int)deprecated
- func (m *CustomTag_Literal) Equal(that interface{}) bool
- func (x *CustomTag_Literal) GetValue() string
- func (m *CustomTag_Literal) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *CustomTag_Literal) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*CustomTag_Literal) ProtoMessage()
- func (x *CustomTag_Literal) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Literal) Reset()
- func (x *CustomTag_Literal) String() string
- type CustomTag_Literal_
- type CustomTag_Metadata
- func (m *CustomTag_Metadata) Clone() proto.Message
- func (*CustomTag_Metadata) Descriptor() ([]byte, []int)deprecated
- func (m *CustomTag_Metadata) Equal(that interface{}) bool
- func (x *CustomTag_Metadata) GetDefaultValue() string
- func (x *CustomTag_Metadata) GetKind() *v3.MetadataKind
- func (x *CustomTag_Metadata) GetMetadataKey() *v3.MetadataKey
- func (m *CustomTag_Metadata) Hash(hasher hash.Hash64) (uint64, error)deprecated
- func (m *CustomTag_Metadata) HashUnique(hasher hash.Hash64) (uint64, error)
- func (*CustomTag_Metadata) ProtoMessage()
- func (x *CustomTag_Metadata) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Metadata) Reset()
- func (x *CustomTag_Metadata) String() string
- type CustomTag_Metadata_
- type CustomTag_RequestHeader
Constants ¶
This section is empty.
Variables ¶
var File_github_com_solo_io_gloo_projects_gloo_api_external_envoy_type_tracing_v3_custom_tag_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CustomTag ¶
type CustomTag struct {
// Used to populate the tag name.
Tag string `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
// Used to specify what kind of custom tag.
//
// Types that are assignable to Type:
//
// *CustomTag_Literal_
// *CustomTag_Environment_
// *CustomTag_RequestHeader
// *CustomTag_Metadata_
Type isCustomTag_Type `protobuf_oneof:"type"`
// contains filtered or unexported fields
}
Describes custom tags for the active span. [#next-free-field: 6]
func (*CustomTag) Descriptor
deprecated
func (*CustomTag) GetEnvironment ¶
func (x *CustomTag) GetEnvironment() *CustomTag_Environment
func (*CustomTag) GetLiteral ¶
func (x *CustomTag) GetLiteral() *CustomTag_Literal
func (*CustomTag) GetMetadata ¶
func (x *CustomTag) GetMetadata() *CustomTag_Metadata
func (*CustomTag) GetRequestHeader ¶
func (x *CustomTag) GetRequestHeader() *CustomTag_Header
func (*CustomTag) Hash
deprecated
added in
v1.6.0
func (*CustomTag) HashUnique ¶ added in v1.17.38
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*CustomTag) ProtoMessage ¶
func (*CustomTag) ProtoMessage()
func (*CustomTag) ProtoReflect ¶ added in v1.6.0
func (x *CustomTag) ProtoReflect() protoreflect.Message
type CustomTag_Environment ¶
type CustomTag_Environment struct {
// Environment variable name to obtain the value to populate the tag value.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// When the environment variable is not found,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string `protobuf:"bytes,2,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Environment type custom tag with environment name and default value.
func (*CustomTag_Environment) Clone ¶ added in v1.8.24
func (m *CustomTag_Environment) Clone() proto.Message
Clone function
func (*CustomTag_Environment) Descriptor
deprecated
func (*CustomTag_Environment) Descriptor() ([]byte, []int)
Deprecated: Use CustomTag_Environment.ProtoReflect.Descriptor instead.
func (*CustomTag_Environment) Equal ¶
func (m *CustomTag_Environment) Equal(that interface{}) bool
Equal function
func (*CustomTag_Environment) GetDefaultValue ¶
func (x *CustomTag_Environment) GetDefaultValue() string
func (*CustomTag_Environment) GetName ¶
func (x *CustomTag_Environment) GetName() string
func (*CustomTag_Environment) Hash
deprecated
added in
v1.6.0
func (m *CustomTag_Environment) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*CustomTag_Environment) HashUnique ¶ added in v1.17.38
func (m *CustomTag_Environment) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*CustomTag_Environment) ProtoMessage ¶
func (*CustomTag_Environment) ProtoMessage()
func (*CustomTag_Environment) ProtoReflect ¶ added in v1.6.0
func (x *CustomTag_Environment) ProtoReflect() protoreflect.Message
func (*CustomTag_Environment) Reset ¶
func (x *CustomTag_Environment) Reset()
func (*CustomTag_Environment) String ¶
func (x *CustomTag_Environment) String() string
type CustomTag_Environment_ ¶
type CustomTag_Environment_ struct {
// An environment custom tag.
Environment *CustomTag_Environment `protobuf:"bytes,3,opt,name=environment,proto3,oneof"`
}
type CustomTag_Header ¶
type CustomTag_Header struct {
// Header name to obtain the value to populate the tag value.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// When the header does not exist,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string `protobuf:"bytes,2,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Header type custom tag with header name and default value.
func (*CustomTag_Header) Clone ¶ added in v1.8.24
func (m *CustomTag_Header) Clone() proto.Message
Clone function
func (*CustomTag_Header) Descriptor
deprecated
func (*CustomTag_Header) Descriptor() ([]byte, []int)
Deprecated: Use CustomTag_Header.ProtoReflect.Descriptor instead.
func (*CustomTag_Header) Equal ¶
func (m *CustomTag_Header) Equal(that interface{}) bool
Equal function
func (*CustomTag_Header) GetDefaultValue ¶
func (x *CustomTag_Header) GetDefaultValue() string
func (*CustomTag_Header) GetName ¶
func (x *CustomTag_Header) GetName() string
func (*CustomTag_Header) Hash
deprecated
added in
v1.6.0
func (m *CustomTag_Header) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*CustomTag_Header) HashUnique ¶ added in v1.17.38
func (m *CustomTag_Header) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*CustomTag_Header) ProtoMessage ¶
func (*CustomTag_Header) ProtoMessage()
func (*CustomTag_Header) ProtoReflect ¶ added in v1.6.0
func (x *CustomTag_Header) ProtoReflect() protoreflect.Message
func (*CustomTag_Header) Reset ¶
func (x *CustomTag_Header) Reset()
func (*CustomTag_Header) String ¶
func (x *CustomTag_Header) String() string
type CustomTag_Literal ¶
type CustomTag_Literal struct {
// Static literal value to populate the tag value.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Literal type custom tag with static value for the tag value.
func (*CustomTag_Literal) Clone ¶ added in v1.8.24
func (m *CustomTag_Literal) Clone() proto.Message
Clone function
func (*CustomTag_Literal) Descriptor
deprecated
func (*CustomTag_Literal) Descriptor() ([]byte, []int)
Deprecated: Use CustomTag_Literal.ProtoReflect.Descriptor instead.
func (*CustomTag_Literal) Equal ¶
func (m *CustomTag_Literal) Equal(that interface{}) bool
Equal function
func (*CustomTag_Literal) GetValue ¶
func (x *CustomTag_Literal) GetValue() string
func (*CustomTag_Literal) Hash
deprecated
added in
v1.6.0
func (m *CustomTag_Literal) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*CustomTag_Literal) HashUnique ¶ added in v1.17.38
func (m *CustomTag_Literal) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*CustomTag_Literal) ProtoMessage ¶
func (*CustomTag_Literal) ProtoMessage()
func (*CustomTag_Literal) ProtoReflect ¶ added in v1.6.0
func (x *CustomTag_Literal) ProtoReflect() protoreflect.Message
func (*CustomTag_Literal) Reset ¶
func (x *CustomTag_Literal) Reset()
func (*CustomTag_Literal) String ¶
func (x *CustomTag_Literal) String() string
type CustomTag_Literal_ ¶
type CustomTag_Literal_ struct {
// A literal custom tag.
Literal *CustomTag_Literal `protobuf:"bytes,2,opt,name=literal,proto3,oneof"`
}
type CustomTag_Metadata ¶
type CustomTag_Metadata struct {
// Specify what kind of metadata to obtain tag value from.
Kind *v3.MetadataKind `protobuf:"bytes,1,opt,name=kind,proto3" json:"kind,omitempty"`
// Metadata key to define the path to retrieve the tag value.
MetadataKey *v3.MetadataKey `protobuf:"bytes,2,opt,name=metadata_key,json=metadataKey,proto3" json:"metadata_key,omitempty"`
// When no valid metadata is found,
// the tag value would be populated with this default value if specified,
// otherwise no tag would be populated.
DefaultValue string `protobuf:"bytes,3,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Metadata type custom tag using MetadataKey to retrieve the protobuf value from Metadata, and populate the tag value with [the canonical JSON](https://developers.google.com/protocol-buffers/docs/proto3#json) representation of it.
func (*CustomTag_Metadata) Clone ¶ added in v1.8.24
func (m *CustomTag_Metadata) Clone() proto.Message
Clone function
func (*CustomTag_Metadata) Descriptor
deprecated
func (*CustomTag_Metadata) Descriptor() ([]byte, []int)
Deprecated: Use CustomTag_Metadata.ProtoReflect.Descriptor instead.
func (*CustomTag_Metadata) Equal ¶
func (m *CustomTag_Metadata) Equal(that interface{}) bool
Equal function
func (*CustomTag_Metadata) GetDefaultValue ¶
func (x *CustomTag_Metadata) GetDefaultValue() string
func (*CustomTag_Metadata) GetKind ¶
func (x *CustomTag_Metadata) GetKind() *v3.MetadataKind
func (*CustomTag_Metadata) GetMetadataKey ¶
func (x *CustomTag_Metadata) GetMetadataKey() *v3.MetadataKey
func (*CustomTag_Metadata) Hash
deprecated
added in
v1.6.0
func (m *CustomTag_Metadata) Hash(hasher hash.Hash64) (uint64, error)
Hash function
Deprecated: due to hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions. Prefer the HashUnique function instead.
func (*CustomTag_Metadata) HashUnique ¶ added in v1.17.38
func (m *CustomTag_Metadata) HashUnique(hasher hash.Hash64) (uint64, error)
HashUnique function generates a hash of the object that is unique to the object by hashing field name and value pairs. Replaces Hash due to original hashing implemention only using field values. The omission of the field name in the hash calculation can lead to hash collisions.
func (*CustomTag_Metadata) ProtoMessage ¶
func (*CustomTag_Metadata) ProtoMessage()
func (*CustomTag_Metadata) ProtoReflect ¶ added in v1.6.0
func (x *CustomTag_Metadata) ProtoReflect() protoreflect.Message
func (*CustomTag_Metadata) Reset ¶
func (x *CustomTag_Metadata) Reset()
func (*CustomTag_Metadata) String ¶
func (x *CustomTag_Metadata) String() string
type CustomTag_Metadata_ ¶
type CustomTag_Metadata_ struct {
// A custom tag to obtain tag value from the metadata.
Metadata *CustomTag_Metadata `protobuf:"bytes,5,opt,name=metadata,proto3,oneof"`
}
type CustomTag_RequestHeader ¶
type CustomTag_RequestHeader struct {
// A request header custom tag.
RequestHeader *CustomTag_Header `protobuf:"bytes,4,opt,name=request_header,json=requestHeader,proto3,oneof"`
}